/***************************************************************************
 *   Copyright (C) 2005 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef DEBUGOUTPUTTEXTEDIT_H
#define DEBUGOUTPUTTEXTEDIT_H

#include <ktextbrowser.h>
#include <qpopupmenu.h>
#include <qpoint.h>

/**
This class is used for showing log content

@author Christoph Thielecke
*/
class DebugOutputTextEdit : public KTextBrowser
{
	Q_OBJECT

public:
	DebugOutputTextEdit( QWidget* parent=0, const char* name=0);
	~DebugOutputTextEdit();
public slots:
	QPopupMenu* createPopupMenu(const QPoint & pos);
	void append ( const QString & text );

private:
	QPopupMenu *popup;

};

#endif
